# Ashby changelog

## [0.1.5] - 2026-02-19
- Updated connector definition (YAML version 0.1.2)
- Source commit: 3f4da97b
- SDK version: 0.1.0

## [0.1.4] - 2026-02-13
- Updated connector definition (YAML version 0.1.2)
- Source commit: 733df4ff
- SDK version: 0.1.0

## [0.1.3] - 2026-02-11
- Updated connector definition (YAML version 0.1.1)
- Source commit: 8c602f77
- SDK version: 0.1.0

## [0.1.2] - 2026-02-11
- Updated connector definition (YAML version 0.1.1)
- Source commit: 114c9599
- SDK version: 0.1.0

## [0.1.1] - 2026-02-11
- Updated connector definition (YAML version 0.1.1)
- Source commit: 64ac3a66
- SDK version: 0.1.0

## [0.1.0] - 2026-02-11
- Updated connector definition (YAML version 0.1.1)
- Source commit: 4376eff9
- SDK version: 0.1.0
